@@ -172,6 +172,7 @@ protected:
 
         void reset() {
             v_zero(prevMag.data(), prevMag.size());
+            v_zero(pendingKick.data(), pendingKick.size());
             v_zero(accumulator.data(), accumulator.size());
             accumulatorFill = 0;
         }
@@ -226,7 +227,7 @@ protected:
         std::unique_ptr<FormantData> formant;
         ChannelData(BinSegmenter::Parameters segmenterParameters,
                     BinClassifier::Parameters classifierParameters,
-                    int longestFftSize,
+                    int /*!!! longestFftSize */,
                     int windowSourceSize,
                     int inRingBufferSize,
                     int outRingBufferSize) :
@@ -241,7 +242,7 @@ protected:
                                BinClassifier::Classification::Residual),
             segmenter(new BinSegmenter(segmenterParameters)),
             segmentation(), prevSegmentation(), nextSegmentation(),
-            mixdown(longestFftSize, 0.f),
+            mixdown(inRingBufferSize, 0.f),
             resampled(outRingBufferSize, 0.f),
             inbuf(new RingBuffer<float>(inRingBufferSize)),
             outbuf(new RingBuffer<float>(outRingBufferSize)),
@@ -252,6 +253,9 @@ protected:
             segmentation = BinSegmenter::Segmentation();
             prevSegmentation = BinSegmenter::Segmentation();
             nextSegmentation = BinSegmenter::Segmentation();
+            for (size_t i = 0; i < nextClassification.size(); ++i) {
+                nextClassification[i] = BinClassifier::Classification::Residual;
+            }
             inbuf->reset();
             outbuf->reset();
             for (auto &s : scales) {
@@ -263,6 +267,7 @@ protected:
     struct ChannelAssembly {
         // Vectors of bare pointers, used to package container data
         // from different channels into arguments for PhaseAdvance
+        FixedVector<const float *> input;
         FixedVector<process_t *> mag;
         FixedVector<process_t *> phase;
         FixedVector<process_t *> prevMag;
@@ -271,6 +276,7 @@ protected:
         FixedVector<float *> mixdown;
         FixedVector<float *> resampled;
         ChannelAssembly(int channels) :
+            input(channels, nullptr),
             mag(channels, nullptr), phase(channels, nullptr),
             prevMag(channels, nullptr), guidance(channels, nullptr),
             outPhase(channels, nullptr), mixdown(channels, nullptr),
@@ -350,6 +356,8 @@ protected:
     };
     ProcessMode m_mode;
 
+    void initialise();
+    void prepareInput(const float *const *input, int ix, int n);
     void consume();
     void createResampler();
     void calculateHop();
@@ -469,6 +477,12 @@ protected:
         }
     }        
 
+    bool useMidSide() const {
+        return m_parameters.channels == 2 &&
+            (m_parameters.options &
+             RubberBandStretcher::OptionChannelsTogether);
+    }
+    
     bool isSingleWindowed() const {
         return m_parameters.options &
             RubberBandStretcher::OptionWindowShort;
