@@ -3,7 +3,7 @@
 /*
     Rubber Band Library
     An audio time-stretching and pitch-shifting library.
-    Copyright 2007-2022 Particular Programs Ltd.
+    Copyright 2007-2023 Particular Programs Ltd.
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -53,6 +53,11 @@ void rubberband_reset(RubberBandState state)
     state->m_s->reset();
 }
 
+int rubberband_get_engine_version(RubberBandState state)
+{
+    return state->m_s->getEngineVersion(); 
+}
+
 void rubberband_set_time_ratio(RubberBandState state, double ratio)
 {
     state->m_s->setTimeRatio(ratio);
@@ -73,6 +78,26 @@ double rubberband_get_pitch_scale(const RubberBandState state)
     return state->m_s->getPitchScale();
 }
 
+void rubberband_set_formant_scale(RubberBandState state, double scale)
+{
+    state->m_s->setFormantScale(scale);
+}
+
+double rubberband_get_formant_scale(const RubberBandState state)
+{
+    return state->m_s->getFormantScale();
+}
+
+unsigned int rubberband_get_preferred_start_pad(const RubberBandState state) 
+{
+    return state->m_s->getPreferredStartPad();
+}
+
+unsigned int rubberband_get_start_delay(const RubberBandState state) 
+{
+    return state->m_s->getStartDelay();
+}
+
 unsigned int rubberband_get_latency(const RubberBandState state) 
 {
     return state->m_s->getLatency();
